@@ -2,7 +2,7 @@
 # Simple tqdm examples and profiling
 
 # Benchmark
-for i in _range(int(1e8)):
+for i in range(int(1e8)):
     pass
 
 # Basic demo
@@ -33,7 +33,7 @@ try:
 except ImportError:
     pass
 else:
-    for i in ProgressBar()(_range(int(1e8))):
+    for i in ProgressBar()(range(int(1e8))):
         pass
 
 # Dynamic miniters benchmark
@@ -61,5 +61,4 @@ for _ in trange(16, leave=True):
 stmts = filter(None, re.split(r'\n\s*#.*?\n', __doc__))
 for s in stmts:
     print(s.replace('import tqdm\n', ''))
-    print(timeit(stmt='try:\n\t_range = xrange'
-                 '\nexcept:\n\t_range = range\n' + s, number=1), 'seconds')
+    print(timeit(stmt=s, number=1), 'seconds')
